# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`infiniband`](#infiniband): Manage InfiniBand support

#### Private Classes

* `infiniband::config`: Manage InfiniBand config
* `infiniband::install`: Install InfiniBand support
* `infiniband::params`: The infiniband default configuration settings.
* `infiniband::providers`: Convenience class to call defined types provided by this module.
* `infiniband::service`: Manage InfiniBand services

### Defined types

* [`infiniband::interface`](#infinibandinterface): Manage IPoIB interface

### Functions

* [`infiniband::calc_log_num_mtt`](#infinibandcalc_log_num_mtt): This function calculates the appropriate value for mlx4_core module's `log_num_mtt` parameter.  The formula is `max_reg_mem = (2^log_num_mtt)

## Classes

### <a name="infiniband"></a>`infiniband`

Manage InfiniBand support

#### Examples

##### 

```puppet
include ::infiniband
```

#### Parameters

The following parameters are available in the `infiniband` class:

* [`extra_packages`](#extra_packages)
* [`rdma_service_ensure`](#rdma_service_ensure)
* [`rdma_service_enable`](#rdma_service_enable)
* [`rdma_service_name`](#rdma_service_name)
* [`rdma_service_has_status`](#rdma_service_has_status)
* [`rdma_service_has_restart`](#rdma_service_has_restart)
* [`ibacm_service_ensure`](#ibacm_service_ensure)
* [`ibacm_service_enable`](#ibacm_service_enable)
* [`ibacm_service_name`](#ibacm_service_name)
* [`ibacm_service_has_status`](#ibacm_service_has_status)
* [`ibacm_service_has_restart`](#ibacm_service_has_restart)
* [`rdma_conf_path`](#rdma_conf_path)
* [`ipoib_load`](#ipoib_load)
* [`srp_load`](#srp_load)
* [`iser_load`](#iser_load)
* [`rds_load`](#rds_load)
* [`fixup_mtrr_regs`](#fixup_mtrr_regs)
* [`nfsordma_load`](#nfsordma_load)
* [`nfsordma_port`](#nfsordma_port)
* [`manage_mlx4_core_options`](#manage_mlx4_core_options)
* [`log_num_mtt`](#log_num_mtt)
* [`log_mtts_per_seg`](#log_mtts_per_seg)
* [`interfaces`](#interfaces)

##### <a name="extra_packages"></a>`extra_packages`

Data type: `Array`

The extra packges to install.

Default value: `[]`

##### <a name="rdma_service_ensure"></a>`rdma_service_ensure`

Data type: `String`

RDMA service ensure parameter.
Default to 'running' if `has_infiniband` fact is 'true', and 'stopped' if 'has_infiniband' fact is 'false'.

Default value: `$infiniband::params::service_ensure`

##### <a name="rdma_service_enable"></a>`rdma_service_enable`

Data type: `Boolean`

RDMA service enable parameter.
Default to true if `has_infiniband` fact is 'true', and false if 'has_infiniband' fact is 'false'.

Default value: `$infiniband::params::service_enable`

##### <a name="rdma_service_name"></a>`rdma_service_name`

Data type: `String`

RDMA service name.

Default value: `$infiniband::params::rdma_service_name`

##### <a name="rdma_service_has_status"></a>`rdma_service_has_status`

Data type: `Boolean`

RDMA service has_status parameter.

Default value: `$infiniband::params::rdma_service_has_status`

##### <a name="rdma_service_has_restart"></a>`rdma_service_has_restart`

Data type: `Boolean`

RDMA service has_restart parameter.

Default value: `$infiniband::params::rdma_service_has_restart`

##### <a name="ibacm_service_ensure"></a>`ibacm_service_ensure`

Data type: `String`

ibacm service ensure parameter.
Default to 'running' if `has_infiniband` fact is 'true', and 'stopped' if 'has_infiniband' fact is 'false'.

Default value: `$infiniband::params::service_ensure`

##### <a name="ibacm_service_enable"></a>`ibacm_service_enable`

Data type: `Boolean`

ibacm service enable parameter.
Default to true if `has_infiniband` fact is 'true', and false if 'has_infiniband' fact is 'false'.

Default value: `$infiniband::params::service_enable`

##### <a name="ibacm_service_name"></a>`ibacm_service_name`

Data type: `String`

ibacm service name.

Default value: `$infiniband::params::ibacm_service_name`

##### <a name="ibacm_service_has_status"></a>`ibacm_service_has_status`

Data type: `Boolean`

ibacm service has_status parameter.

Default value: `$infiniband::params::ibacm_service_has_status`

##### <a name="ibacm_service_has_restart"></a>`ibacm_service_has_restart`

Data type: `Boolean`

ibacm service has_restart parameter.

Default value: `$infiniband::params::ibacm_service_has_restart`

##### <a name="rdma_conf_path"></a>`rdma_conf_path`

Data type: `Stdlib::Absolutepath`

The RDMA service configuration path.

Default value: `$infiniband::params::rdma_conf_path`

##### <a name="ipoib_load"></a>`ipoib_load`

Data type: `Enum['yes', 'no']`

Sets the `IPOIB_LOAD` setting for the RDMA service.

Default value: `'yes'`

##### <a name="srp_load"></a>`srp_load`

Data type: `Enum['yes', 'no']`

Sets the `SRP_LOAD` setting for the RDMA service.

Default value: `'no'`

##### <a name="iser_load"></a>`iser_load`

Data type: `Enum['yes', 'no']`

Sets the `ISER_LOAD` setting for the RDMA service.

Default value: `'no'`

##### <a name="rds_load"></a>`rds_load`

Data type: `Enum['yes', 'no']`

Sets the `RDS_LOAD` setting for the RDMA service.

Default value: `'no'`

##### <a name="fixup_mtrr_regs"></a>`fixup_mtrr_regs`

Data type: `Enum['yes', 'no']`

Sets the `FIXUP_MTRR_REGS` setting for the RDMA service.

Default value: `'no'`

##### <a name="nfsordma_load"></a>`nfsordma_load`

Data type: `Enum['yes', 'no']`

Sets the `NFSoRDMA_LOAD` setting for the RDMA service.

Default value: `'yes'`

##### <a name="nfsordma_port"></a>`nfsordma_port`

Data type: `Integer[0, 65535]`

Sets the `NFSoRDMA_PORT` setting for the RDMA service.

Default value: `2050`

##### <a name="manage_mlx4_core_options"></a>`manage_mlx4_core_options`

Data type: `Boolean`

Boolean that determines if '/etc/modprobe.d/mlx4_core.conf' should be managed.

Default value: ``true``

##### <a name="log_num_mtt"></a>`log_num_mtt`

Data type: `Optional[Integer]`

Sets the mlx4_core module's 'log_num_mtt' value.
When the value is undef the value is determined using the `calc_log_num_mtt` parser function.

Default value: ``undef``

##### <a name="log_mtts_per_seg"></a>`log_mtts_per_seg`

Data type: `Integer`

Sets the mlx4_core module's 'log_mtts_per_seq' value.

Default value: `3`

##### <a name="interfaces"></a>`interfaces`

Data type: `Hash`

This Hash can be used to define `infiniband::interface` resources.

Default value: `{}`

## Defined types

### <a name="infinibandinterface"></a>`infiniband::interface`

Manage IPoIB interface

#### Examples

##### Creates the ifcfg file for an IBoIP interface

```puppet
infiniband::interface { 'ib0':
  ipaddr  => '192.168.1.1',
  netmask => '255.255.255.0',
}
```

#### Parameters

The following parameters are available in the `infiniband::interface` defined type:

* [`name`](#name)
* [`ipaddr`](#ipaddr)
* [`netmask`](#netmask)
* [`gateway`](#gateway)
* [`ensure`](#ensure)
* [`enable`](#enable)
* [`connected_mode`](#connected_mode)
* [`mtu`](#mtu)
* [`bonding`](#bonding)
* [`bonding_slaves`](#bonding_slaves)
* [`bonding_opts`](#bonding_opts)

##### <a name="name"></a>`name`

The resource title.  Sets the interfaces name, for example 'ib0'.

##### <a name="ipaddr"></a>`ipaddr`

Data type: `Stdlib::Compat::Ip_address`

The IPADDR for the infiniband interface.

##### <a name="netmask"></a>`netmask`

Data type: `Stdlib::Compat::Ip_address`

The NETMASK for the infiniband interface.

##### <a name="gateway"></a>`gateway`

Data type: `Optional[Stdlib::Compat::Ip_address]`

The GATEWAY for the infiniband interface.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Sets if the infiniband::interface should be present or absent.

Default value: `'present'`

##### <a name="enable"></a>`enable`

Data type: `Boolean`

Sets if the infiniband::interface should be enabled at boot.

Default value: ``true``

##### <a name="connected_mode"></a>`connected_mode`

Data type: `Enum['yes', 'no']`

The CONNECTED_MODE value for the infiniband interface.

Default value: `'yes'`

##### <a name="mtu"></a>`mtu`

Data type: `Optional[Integer]`

The MTU for the infiniband interface.

Default value: ``undef``

##### <a name="bonding"></a>`bonding`

Data type: `Boolean`

If this interface is a bonding interface (true/false); defaults to false

Default value: ``false``

##### <a name="bonding_slaves"></a>`bonding_slaves`

Data type: `Array[String]`

Array of interfaces that should be enslaved in the bonding interface

Default value: `[]`

##### <a name="bonding_opts"></a>`bonding_opts`

Data type: `String`

The bonding options to use for this bonding interface

Default value: `'mode=active-backup miimon=100'`

## Functions

### <a name="infinibandcalc_log_num_mtt"></a>`infiniband::calc_log_num_mtt`

Type: Ruby 4.x API

This function calculates the appropriate value for mlx4_core module's `log_num_mtt` parameter.

The formula is `max_reg_mem = (2^log_num_mtt) * (2^log_mtts_per_seg) * (page_size_bytes)`.  This function finds the
log_num_mtt necessary to make 'max_reg_mem' twice the size of system's RAM.  Ref: http://community.mellanox.com/docs/DOC-1120.

#### Examples

##### Using system memory size to calculate value

```puppet
infiniband::calc_log_num_mtt($facts['memory']['system']['total_bytes'])
```

#### `infiniband::calc_log_num_mtt(Optional[Variant[Undef,Integer,Float]] $mem, Optional[Integer] $log_mtts_per_seg, Optional[Integer] $page_size_bytes)`

This function calculates the appropriate value for mlx4_core module's `log_num_mtt` parameter.

The formula is `max_reg_mem = (2^log_num_mtt) * (2^log_mtts_per_seg) * (page_size_bytes)`.  This function finds the
log_num_mtt necessary to make 'max_reg_mem' twice the size of system's RAM.  Ref: http://community.mellanox.com/docs/DOC-1120.

Returns: `Integer` The calculated log_num_mtt value

##### Examples

###### Using system memory size to calculate value

```puppet
infiniband::calc_log_num_mtt($facts['memory']['system']['total_bytes'])
```

##### `mem`

Data type: `Optional[Variant[Undef,Integer,Float]]`

The system memory in bytes

##### `log_mtts_per_seg`

Data type: `Optional[Integer]`

The value for log_mtts_per_seg.  Defaults to `3` if undefined.

##### `page_size_bytes`

Data type: `Optional[Integer]`

The system's page size in bytes.  Defaults to `4096` if undefined.

